import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:stopmotion/cubit/bottom_nav_cubit.dart';
import 'package:stopmotion/ui/screens/camera.dart';
import 'package:stopmotion/ui/screens/settings.dart';
import 'package:stopmotion/ui/screens/home.dart';

class BottomNavBar extends StatelessWidget {
  const BottomNavBar({super.key});

  @override
  Widget build(BuildContext context) {
    return Card(
      margin: const EdgeInsets.only(top: 1, right: 4, left: 4),
      elevation: 4,
      shadowColor: Theme.of(context).colorScheme.shadow,
      color: Theme.of(context).colorScheme.surfaceVariant,
      shape: const RoundedRectangleBorder(
        borderRadius: BorderRadius.only(
          topLeft: Radius.circular(16),
          topRight: Radius.circular(16),
        ),
      ),
      child: BlocBuilder<BottomNavCubit, int>(builder: (BuildContext context, int state) {
        return BottomNavigationBar(
          currentIndex: state,
          onTap: (int index) => context.read<BottomNavCubit>().updateIndex(index),
          type: BottomNavigationBarType.fixed,
          elevation: 0,
          backgroundColor: Colors.transparent,
          selectedItemColor: Theme.of(context).colorScheme.primary,
          unselectedItemColor: Theme.of(context).textTheme.bodySmall!.color,
          items: <BottomNavigationBarItem>[
            BottomNavigationBarItem(
              icon: ScreenHome.navBarIcon,
              label: tr(ScreenHome.navBarText),
            ),
            BottomNavigationBarItem(
              icon: ScreenCamera.navBarIcon,
              label: tr(ScreenCamera.navBarText),
            ),
            BottomNavigationBarItem(
              icon: ScreenSettings.navBarIcon,
              label: tr(ScreenSettings.navBarText),
            ),
          ],
        );
      }),
    );
  }
}
